// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: protobuf-c/protobuf-c.proto
// Protobuf C++ Version: 7.35.0

#ifndef protobuf_2dc_2fprotobuf_2dc_2eproto_2epb_2eh
#define protobuf_2dc_2fprotobuf_2dc_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

// clang-format off
#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 7035000
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/unknown_field_set.h"
#include "google/protobuf/descriptor.pb.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_protobuf_2dc_2fprotobuf_2dc_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_protobuf_2dc_2fprotobuf_2dc_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_protobuf_2dc_2fprotobuf_2dc_2eproto;
}  // extern "C"
class ProtobufCFieldOptions;
struct ProtobufCFieldOptionsGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern ProtobufCFieldOptionsGlobalsTypeInternal ProtobufCFieldOptions_globals_;
extern const ::google::protobuf::internal::ClassDataFull ProtobufCFieldOptions_class_data_;
#else
extern const ProtobufCFieldOptionsGlobalsTypeInternal ProtobufCFieldOptions_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class ProtobufCFileOptions;
struct ProtobufCFileOptionsGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern ProtobufCFileOptionsGlobalsTypeInternal ProtobufCFileOptions_globals_;
extern const ::google::protobuf::internal::ClassDataFull ProtobufCFileOptions_class_data_;
#else
extern const ProtobufCFileOptionsGlobalsTypeInternal ProtobufCFileOptions_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class ProtobufCMessageOptions;
struct ProtobufCMessageOptionsGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern ProtobufCMessageOptionsGlobalsTypeInternal ProtobufCMessageOptions_globals_;
extern const ::google::protobuf::internal::ClassDataFull ProtobufCMessageOptions_class_data_;
#else
extern const ProtobufCMessageOptionsGlobalsTypeInternal ProtobufCMessageOptions_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google


// ===================================================================


// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED ProtobufCMessageOptions final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:ProtobufCMessageOptions) */ {
 public:
  inline ProtobufCMessageOptions() : ProtobufCMessageOptions(nullptr) {}
  ~ProtobufCMessageOptions() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(ProtobufCMessageOptions* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(ProtobufCMessageOptions));
  }
#endif

  template <typename = void>
  explicit constexpr ProtobufCMessageOptions(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline ProtobufCMessageOptions(const ProtobufCMessageOptions& from) : ProtobufCMessageOptions(nullptr, from) {}
  inline ProtobufCMessageOptions(ProtobufCMessageOptions&& from) noexcept : ProtobufCMessageOptions(nullptr, ::std::move(from)) {}
  inline ProtobufCMessageOptions& operator=(const ProtobufCMessageOptions& from) {
    CopyFrom(from);
    return *this;
  }
  inline ProtobufCMessageOptions& operator=(ProtobufCMessageOptions&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const ProtobufCMessageOptions& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<ProtobufCMessageOptions>(&ProtobufCMessageOptions_globals_);
  }
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(ProtobufCMessageOptions& a, ProtobufCMessageOptions& b) { a.Swap(&b); }
  inline void Swap(ProtobufCMessageOptions* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ProtobufCMessageOptions* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] ProtobufCMessageOptions* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<ProtobufCMessageOptions>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const ProtobufCMessageOptions& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const ProtobufCMessageOptions& from) { ProtobufCMessageOptions::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(ProtobufCMessageOptions* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "ProtobufCMessageOptions"; }

  explicit ProtobufCMessageOptions(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  ProtobufCMessageOptions(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const ProtobufCMessageOptions& from);
  ProtobufCMessageOptions(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, ProtobufCMessageOptions&& from) noexcept
      : ProtobufCMessageOptions(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kBaseFieldNameFieldNumber = 3,
    kGenPackHelpersFieldNumber = 1,
    kGenInitHelpersFieldNumber = 2,
  };
  // optional string base_field_name = 3 [default = "base"];
  [[nodiscard]] bool has_base_field_name()
      const;
  void clear_base_field_name() ;
  [[nodiscard]] const ::std::string& base_field_name() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_base_field_name(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_base_field_name();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_base_field_name();
  void set_allocated_base_field_name(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_base_field_name() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_base_field_name(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_base_field_name();

  public:
  // optional bool gen_pack_helpers = 1 [default = false];
  [[nodiscard]] bool has_gen_pack_helpers()
      const;
  void clear_gen_pack_helpers() ;
  [[nodiscard]] bool gen_pack_helpers() const;
  void set_gen_pack_helpers(bool value);

  private:
  bool _internal_gen_pack_helpers() const;
  void _internal_set_gen_pack_helpers(bool value);

  public:
  // optional bool gen_init_helpers = 2 [default = true];
  [[nodiscard]] bool has_gen_init_helpers()
      const;
  void clear_gen_init_helpers() ;
  [[nodiscard]] bool gen_init_helpers() const;
  void set_gen_init_helpers(bool value);

  private:
  bool _internal_gen_init_helpers() const;
  void _internal_set_gen_init_helpers(bool value);

  public:
  // @@protoc_insertion_point(class_scope:ProtobufCMessageOptions)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<2, 3,
                          0, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const ProtobufCMessageOptions& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    static const ::google::protobuf::internal::LazyString _i_give_permission_to_break_this_code_default_base_field_name_;
    ::google::protobuf::internal::ArenaStringPtr base_field_name_;
    bool gen_pack_helpers_;
    bool gen_init_helpers_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_protobuf_2dc_2fprotobuf_2dc_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED ProtobufCFileOptions final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:ProtobufCFileOptions) */ {
 public:
  inline ProtobufCFileOptions() : ProtobufCFileOptions(nullptr) {}
  ~ProtobufCFileOptions() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(ProtobufCFileOptions* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(ProtobufCFileOptions));
  }
#endif

  template <typename = void>
  explicit constexpr ProtobufCFileOptions(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline ProtobufCFileOptions(const ProtobufCFileOptions& from) : ProtobufCFileOptions(nullptr, from) {}
  inline ProtobufCFileOptions(ProtobufCFileOptions&& from) noexcept : ProtobufCFileOptions(nullptr, ::std::move(from)) {}
  inline ProtobufCFileOptions& operator=(const ProtobufCFileOptions& from) {
    CopyFrom(from);
    return *this;
  }
  inline ProtobufCFileOptions& operator=(ProtobufCFileOptions&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const ProtobufCFileOptions& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<ProtobufCFileOptions>(&ProtobufCFileOptions_globals_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(ProtobufCFileOptions& a, ProtobufCFileOptions& b) { a.Swap(&b); }
  inline void Swap(ProtobufCFileOptions* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ProtobufCFileOptions* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] ProtobufCFileOptions* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<ProtobufCFileOptions>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const ProtobufCFileOptions& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const ProtobufCFileOptions& from) { ProtobufCFileOptions::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(ProtobufCFileOptions* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "ProtobufCFileOptions"; }

  explicit ProtobufCFileOptions(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  ProtobufCFileOptions(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const ProtobufCFileOptions& from);
  ProtobufCFileOptions(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, ProtobufCFileOptions&& from) noexcept
      : ProtobufCFileOptions(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kCPackageFieldNumber = 6,
    kNoGenerateFieldNumber = 1,
    kConstStringsFieldNumber = 4,
    kUseOneofFieldNameFieldNumber = 5,
    kGenPackHelpersFieldNumber = 2,
    kGenInitHelpersFieldNumber = 3,
  };
  // optional string c_package = 6;
  [[nodiscard]] bool has_c_package()
      const;
  void clear_c_package() ;
  [[nodiscard]] const ::std::string& c_package() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_c_package(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_c_package();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_c_package();
  void set_allocated_c_package(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_c_package() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_c_package(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_c_package();

  public:
  // optional bool no_generate = 1 [default = false];
  [[nodiscard]] bool has_no_generate()
      const;
  void clear_no_generate() ;
  [[nodiscard]] bool no_generate() const;
  void set_no_generate(bool value);

  private:
  bool _internal_no_generate() const;
  void _internal_set_no_generate(bool value);

  public:
  // optional bool const_strings = 4 [default = false];
  [[nodiscard]] bool has_const_strings()
      const;
  void clear_const_strings() ;
  [[nodiscard]] bool const_strings() const;
  void set_const_strings(bool value);

  private:
  bool _internal_const_strings() const;
  void _internal_set_const_strings(bool value);

  public:
  // optional bool use_oneof_field_name = 5 [default = false];
  [[nodiscard]] bool has_use_oneof_field_name()
      const;
  void clear_use_oneof_field_name() ;
  [[nodiscard]] bool use_oneof_field_name() const;
  void set_use_oneof_field_name(bool value);

  private:
  bool _internal_use_oneof_field_name() const;
  void _internal_set_use_oneof_field_name(bool value);

  public:
  // optional bool gen_pack_helpers = 2 [default = true];
  [[nodiscard]] bool has_gen_pack_helpers()
      const;
  void clear_gen_pack_helpers() ;
  [[nodiscard]] bool gen_pack_helpers() const;
  void set_gen_pack_helpers(bool value);

  private:
  bool _internal_gen_pack_helpers() const;
  void _internal_set_gen_pack_helpers(bool value);

  public:
  // optional bool gen_init_helpers = 3 [default = true];
  [[nodiscard]] bool has_gen_init_helpers()
      const;
  void clear_gen_init_helpers() ;
  [[nodiscard]] bool gen_init_helpers() const;
  void set_gen_init_helpers(bool value);

  private:
  bool _internal_gen_init_helpers() const;
  void _internal_set_gen_init_helpers(bool value);

  public:
  // @@protoc_insertion_point(class_scope:ProtobufCFileOptions)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<3, 6,
                          0, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const ProtobufCFileOptions& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr c_package_;
    bool no_generate_;
    bool const_strings_;
    bool use_oneof_field_name_;
    bool gen_pack_helpers_;
    bool gen_init_helpers_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_protobuf_2dc_2fprotobuf_2dc_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED ProtobufCFieldOptions final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:ProtobufCFieldOptions) */ {
 public:
  inline ProtobufCFieldOptions() : ProtobufCFieldOptions(nullptr) {}
  ~ProtobufCFieldOptions() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(ProtobufCFieldOptions* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(ProtobufCFieldOptions));
  }
#endif

  template <typename = void>
  explicit constexpr ProtobufCFieldOptions(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline ProtobufCFieldOptions(const ProtobufCFieldOptions& from) : ProtobufCFieldOptions(nullptr, from) {}
  inline ProtobufCFieldOptions(ProtobufCFieldOptions&& from) noexcept : ProtobufCFieldOptions(nullptr, ::std::move(from)) {}
  inline ProtobufCFieldOptions& operator=(const ProtobufCFieldOptions& from) {
    CopyFrom(from);
    return *this;
  }
  inline ProtobufCFieldOptions& operator=(ProtobufCFieldOptions&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const ProtobufCFieldOptions& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<ProtobufCFieldOptions>(&ProtobufCFieldOptions_globals_);
  }
  static constexpr int kIndexInFileMessages = 2;
  friend void swap(ProtobufCFieldOptions& a, ProtobufCFieldOptions& b) { a.Swap(&b); }
  inline void Swap(ProtobufCFieldOptions* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ProtobufCFieldOptions* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] ProtobufCFieldOptions* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<ProtobufCFieldOptions>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const ProtobufCFieldOptions& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const ProtobufCFieldOptions& from) { ProtobufCFieldOptions::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(ProtobufCFieldOptions* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "ProtobufCFieldOptions"; }

  explicit ProtobufCFieldOptions(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  ProtobufCFieldOptions(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const ProtobufCFieldOptions& from);
  ProtobufCFieldOptions(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, ProtobufCFieldOptions&& from) noexcept
      : ProtobufCFieldOptions(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kStringAsBytesFieldNumber = 1,
  };
  // optional bool string_as_bytes = 1 [default = false];
  [[nodiscard]] bool has_string_as_bytes()
      const;
  void clear_string_as_bytes() ;
  [[nodiscard]] bool string_as_bytes() const;
  void set_string_as_bytes(bool value);

  private:
  bool _internal_string_as_bytes() const;
  void _internal_set_string_as_bytes(bool value);

  public:
  // @@protoc_insertion_point(class_scope:ProtobufCFieldOptions)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<0, 1,
                          0, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const ProtobufCFieldOptions& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    bool string_as_bytes_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_protobuf_2dc_2fprotobuf_2dc_2eproto;
};

// ===================================================================



inline constexpr int kPbCFileFieldNumber = 1019;
extern ::google::protobuf::internal::ExtensionIdentifier<
    ::google::protobuf::FileOptions, ::google::protobuf::internal::MessageTypeTraits< ::ProtobufCFileOptions >, 11, false>(pb_c_file);
inline constexpr int kPbCMsgFieldNumber = 1019;
extern ::google::protobuf::internal::ExtensionIdentifier<
    ::google::protobuf::MessageOptions, ::google::protobuf::internal::MessageTypeTraits< ::ProtobufCMessageOptions >, 11, false>(pb_c_msg);
inline constexpr int kPbCFieldFieldNumber = 1019;
extern ::google::protobuf::internal::ExtensionIdentifier<
    ::google::protobuf::FieldOptions, ::google::protobuf::internal::MessageTypeTraits< ::ProtobufCFieldOptions >, 11, false>(pb_c_field);

// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// ProtobufCFileOptions

// optional bool no_generate = 1 [default = false];
inline bool ProtobufCFileOptions::has_no_generate() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000002U);
  return value;
}
inline void ProtobufCFileOptions::clear_no_generate() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.no_generate_ = false;
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline bool ProtobufCFileOptions::no_generate() const {
  // @@protoc_insertion_point(field_get:ProtobufCFileOptions.no_generate)
  return _internal_no_generate();
}
inline void ProtobufCFileOptions::set_no_generate(bool value) {
  _internal_set_no_generate(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_set:ProtobufCFileOptions.no_generate)
}
inline bool ProtobufCFileOptions::_internal_no_generate() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.no_generate_;
}
inline void ProtobufCFileOptions::_internal_set_no_generate(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.no_generate_ = value;
}

// optional bool gen_pack_helpers = 2 [default = true];
inline bool ProtobufCFileOptions::has_gen_pack_helpers() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000010U);
  return value;
}
inline void ProtobufCFileOptions::clear_gen_pack_helpers() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.gen_pack_helpers_ = true;
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
inline bool ProtobufCFileOptions::gen_pack_helpers() const {
  // @@protoc_insertion_point(field_get:ProtobufCFileOptions.gen_pack_helpers)
  return _internal_gen_pack_helpers();
}
inline void ProtobufCFileOptions::set_gen_pack_helpers(bool value) {
  _internal_set_gen_pack_helpers(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  // @@protoc_insertion_point(field_set:ProtobufCFileOptions.gen_pack_helpers)
}
inline bool ProtobufCFileOptions::_internal_gen_pack_helpers() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.gen_pack_helpers_;
}
inline void ProtobufCFileOptions::_internal_set_gen_pack_helpers(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.gen_pack_helpers_ = value;
}

// optional bool gen_init_helpers = 3 [default = true];
inline bool ProtobufCFileOptions::has_gen_init_helpers() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000020U);
  return value;
}
inline void ProtobufCFileOptions::clear_gen_init_helpers() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.gen_init_helpers_ = true;
  ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
}
inline bool ProtobufCFileOptions::gen_init_helpers() const {
  // @@protoc_insertion_point(field_get:ProtobufCFileOptions.gen_init_helpers)
  return _internal_gen_init_helpers();
}
inline void ProtobufCFileOptions::set_gen_init_helpers(bool value) {
  _internal_set_gen_init_helpers(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  // @@protoc_insertion_point(field_set:ProtobufCFileOptions.gen_init_helpers)
}
inline bool ProtobufCFileOptions::_internal_gen_init_helpers() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.gen_init_helpers_;
}
inline void ProtobufCFileOptions::_internal_set_gen_init_helpers(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.gen_init_helpers_ = value;
}

// optional bool const_strings = 4 [default = false];
inline bool ProtobufCFileOptions::has_const_strings() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  return value;
}
inline void ProtobufCFileOptions::clear_const_strings() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.const_strings_ = false;
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline bool ProtobufCFileOptions::const_strings() const {
  // @@protoc_insertion_point(field_get:ProtobufCFileOptions.const_strings)
  return _internal_const_strings();
}
inline void ProtobufCFileOptions::set_const_strings(bool value) {
  _internal_set_const_strings(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_set:ProtobufCFileOptions.const_strings)
}
inline bool ProtobufCFileOptions::_internal_const_strings() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.const_strings_;
}
inline void ProtobufCFileOptions::_internal_set_const_strings(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.const_strings_ = value;
}

// optional bool use_oneof_field_name = 5 [default = false];
inline bool ProtobufCFileOptions::has_use_oneof_field_name() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000008U);
  return value;
}
inline void ProtobufCFileOptions::clear_use_oneof_field_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.use_oneof_field_name_ = false;
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
}
inline bool ProtobufCFileOptions::use_oneof_field_name() const {
  // @@protoc_insertion_point(field_get:ProtobufCFileOptions.use_oneof_field_name)
  return _internal_use_oneof_field_name();
}
inline void ProtobufCFileOptions::set_use_oneof_field_name(bool value) {
  _internal_set_use_oneof_field_name(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  // @@protoc_insertion_point(field_set:ProtobufCFileOptions.use_oneof_field_name)
}
inline bool ProtobufCFileOptions::_internal_use_oneof_field_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.use_oneof_field_name_;
}
inline void ProtobufCFileOptions::_internal_set_use_oneof_field_name(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.use_oneof_field_name_ = value;
}

// optional string c_package = 6;
inline bool ProtobufCFileOptions::has_c_package() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000001U);
  return value;
}
inline void ProtobufCFileOptions::clear_c_package() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.c_package_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& ProtobufCFileOptions::c_package() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:ProtobufCFileOptions.c_package)
  return _internal_c_package();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void ProtobufCFileOptions::set_c_package(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.c_package_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:ProtobufCFileOptions.c_package)
}
inline ::std::string* PROTOBUF_NONNULL ProtobufCFileOptions::mutable_c_package()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_c_package();
  // @@protoc_insertion_point(field_mutable:ProtobufCFileOptions.c_package)
  return _s;
}
inline const ::std::string& ProtobufCFileOptions::_internal_c_package() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.c_package_.Get();
}
inline void ProtobufCFileOptions::_internal_set_c_package(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.c_package_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL ProtobufCFileOptions::_internal_mutable_c_package() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.c_package_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE ProtobufCFileOptions::release_c_package() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:ProtobufCFileOptions.c_package)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.c_package_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.c_package_.Set("", GetArena());
  }
  return released;
}
inline void ProtobufCFileOptions::set_allocated_c_package(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.c_package_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.c_package_.IsDefault()) {
    _impl_.c_package_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:ProtobufCFileOptions.c_package)
}

// -------------------------------------------------------------------

// ProtobufCMessageOptions

// optional bool gen_pack_helpers = 1 [default = false];
inline bool ProtobufCMessageOptions::has_gen_pack_helpers() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000002U);
  return value;
}
inline void ProtobufCMessageOptions::clear_gen_pack_helpers() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.gen_pack_helpers_ = false;
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline bool ProtobufCMessageOptions::gen_pack_helpers() const {
  // @@protoc_insertion_point(field_get:ProtobufCMessageOptions.gen_pack_helpers)
  return _internal_gen_pack_helpers();
}
inline void ProtobufCMessageOptions::set_gen_pack_helpers(bool value) {
  _internal_set_gen_pack_helpers(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_set:ProtobufCMessageOptions.gen_pack_helpers)
}
inline bool ProtobufCMessageOptions::_internal_gen_pack_helpers() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.gen_pack_helpers_;
}
inline void ProtobufCMessageOptions::_internal_set_gen_pack_helpers(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.gen_pack_helpers_ = value;
}

// optional bool gen_init_helpers = 2 [default = true];
inline bool ProtobufCMessageOptions::has_gen_init_helpers() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  return value;
}
inline void ProtobufCMessageOptions::clear_gen_init_helpers() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.gen_init_helpers_ = true;
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline bool ProtobufCMessageOptions::gen_init_helpers() const {
  // @@protoc_insertion_point(field_get:ProtobufCMessageOptions.gen_init_helpers)
  return _internal_gen_init_helpers();
}
inline void ProtobufCMessageOptions::set_gen_init_helpers(bool value) {
  _internal_set_gen_init_helpers(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_set:ProtobufCMessageOptions.gen_init_helpers)
}
inline bool ProtobufCMessageOptions::_internal_gen_init_helpers() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.gen_init_helpers_;
}
inline void ProtobufCMessageOptions::_internal_set_gen_init_helpers(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.gen_init_helpers_ = value;
}

// optional string base_field_name = 3 [default = "base"];
inline bool ProtobufCMessageOptions::has_base_field_name() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000001U);
  return value;
}
inline void ProtobufCMessageOptions::clear_base_field_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.base_field_name_.ClearToDefault(::ProtobufCMessageOptions::Impl_::_i_give_permission_to_break_this_code_default_base_field_name_, GetArena());
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& ProtobufCMessageOptions::base_field_name() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:ProtobufCMessageOptions.base_field_name)
  if (_impl_.base_field_name_.IsDefault()) {
    return Impl_::_i_give_permission_to_break_this_code_default_base_field_name_.get();
  }
  return _internal_base_field_name();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void ProtobufCMessageOptions::set_base_field_name(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.base_field_name_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:ProtobufCMessageOptions.base_field_name)
}
inline ::std::string* PROTOBUF_NONNULL ProtobufCMessageOptions::mutable_base_field_name()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_base_field_name();
  // @@protoc_insertion_point(field_mutable:ProtobufCMessageOptions.base_field_name)
  return _s;
}
inline const ::std::string& ProtobufCMessageOptions::_internal_base_field_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.base_field_name_.Get();
}
inline void ProtobufCMessageOptions::_internal_set_base_field_name(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.base_field_name_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL ProtobufCMessageOptions::_internal_mutable_base_field_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.base_field_name_.Mutable(::ProtobufCMessageOptions::Impl_::_i_give_permission_to_break_this_code_default_base_field_name_, GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE ProtobufCMessageOptions::release_base_field_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:ProtobufCMessageOptions.base_field_name)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  return _impl_.base_field_name_.Release();
}
inline void ProtobufCMessageOptions::set_allocated_base_field_name(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.base_field_name_.SetAllocated(value, GetArena());
  // @@protoc_insertion_point(field_set_allocated:ProtobufCMessageOptions.base_field_name)
}

// -------------------------------------------------------------------

// ProtobufCFieldOptions

// optional bool string_as_bytes = 1 [default = false];
inline bool ProtobufCFieldOptions::has_string_as_bytes() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000001U);
  return value;
}
inline void ProtobufCFieldOptions::clear_string_as_bytes() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.string_as_bytes_ = false;
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline bool ProtobufCFieldOptions::string_as_bytes() const {
  // @@protoc_insertion_point(field_get:ProtobufCFieldOptions.string_as_bytes)
  return _internal_string_as_bytes();
}
inline void ProtobufCFieldOptions::set_string_as_bytes(bool value) {
  _internal_set_string_as_bytes(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_set:ProtobufCFieldOptions.string_as_bytes)
}
inline bool ProtobufCFieldOptions::_internal_string_as_bytes() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.string_as_bytes_;
}
inline void ProtobufCFieldOptions::_internal_set_string_as_bytes(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.string_as_bytes_ = value;
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)


// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"
// clang-format on

#endif  // protobuf_2dc_2fprotobuf_2dc_2eproto_2epb_2eh
